from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from karix.api.accounts_api import AccountsApi
from karix.api.message_api import MessageApi
from karix.api.number_api import NumberApi
from karix.api.number_search_api import NumberSearchApi
from karix.api.webhook_api import WebhookApi



# coding: utf-8

"""
    karix api

    # Karix API lets you interact with the Karix platform. It allows you to query your account, set up webhooks, send messages and buy phone numbers.   # noqa: E501

    OpenAPI spec version: 1.0
    Contact: support@karix.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "karix"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Python helper for karix.io",
    author_email="support@karix.com",
    url="https://github.com/karixtech/karix-python",
    keywords=["sms", "karix"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Karix API lets you interact with the Karix platform. It allows you to query your account, set up webhooks, send messages and buy phone numbers.   # noqa: E501
    """
)
